@@ -2,4 +2,4 @@ from .loader import load_entry_points
 
 
 main = load_entry_points()
-main()
+# main object is called by the console script.
